import { Context, Inject, Provide } from '@midwayjs/core';
import { InjectEntityModel } from '@midwayjs/typeorm';
import { Repository } from 'typeorm';
import { Course } from '../entity/course.entity';
import { nanoid } from 'nanoid';

export interface ICourseCreate {
  course_title: string;
  course_summary: string;
  course_cover_url: string;
}

@Provide()
export class CourseService {
  @Inject()
  ctx: Context;

  @InjectEntityModel(Course)
  courseModel: Repository<Course>;

  async create(course: Course) {
    course.course_id = nanoid(13);
    const courseCreateRes = await this.courseModel.save(course);
    return courseCreateRes.course_id;
  }

  async selectAll() {
    return await this.courseModel.find({ where: { valid: true } });
  }

  async select(course: Course) {
    const { course_id } = course;
    return await this.courseModel.findOne({ where: { course_id } });
  }
}
